import java.io.IOException;
import java.io.InputStream;

import ch.ethz.ssh2.Connection;
import ch.ethz.ssh2.ServerHostKeyVerifier;
import ch.ethz.ssh2.Session;

/**
 * SSH2Demo1. A simple demo that executes "ls -la" on a server.
 * 
 * @author Christian Plattner, plattner@inf.ethz.ch
 * @version $Id: SSH2Demo1.java,v 1.2 2005/06/27 07:33:40 cplattne Exp $
 * 
 */
public class SSH2Demo1 implements ServerHostKeyVerifier
{

	public void work(String host, int port, String user, String password)
	{
		Connection sshc = new Connection(host, port);

		try
		{
			/* Connect and register callback */

			sshc.connect(this);

			/* Authenticate */

			boolean res = sshc.authenticateWithPassword(user, password);

			if (res == false)
			{
				throw new IOException("Could not authenticate!");
			}

			/* Create a session */

			Session sess = sshc.openSession();

			/* Request a dumb terminal and execute "ls -la" */

			sess.requestDumbPTY();
			sess.execCommand("ls -la");

			/*
			 * We assume here that a PTY will never send us data on the stderr
			 * channel (stderr will be "mixed" into the terminal screen).
			 */

			InputStream is = sess.getStdout();

			while (true)
			{
				int c = is.read();
				if (c == -1)
					break;
				System.out.print((char) c);
				
				/*
				 * Ideally, you should try to read/write more than 1 byte at a
				 * time. 
				 */
			}

			/*
			 * Show exit code, if available (may be NULL if the server did not
			 * send it, happens occasionally with OpenSSH).
			 */

			System.out.println("ExitCode: " + sess.getExitStatus());

		}
		catch (IOException e)
		{
			e.printStackTrace();
		}
		finally
		{
			/* Close the connection (=> stop the receiver thread) */

			sshc.close();
		}
	}

	public boolean verifyServerHostKey(String hostname, int port, String serverHostKeyAlgorithm, byte[] serverHostKey)
	{
		System.out.println("Checking key from " + hostname + ":" + port);

		/* Should compare the key with an entry in a database */

		return true;
	}

	public static void main(String[] args)
	{
		SSH2Demo1 demo1 = new SSH2Demo1();
		demo1.work("HOST", 22, "USER", "PASSWORD");
	}
}
